Class: Unmagic::Icon::Configuration
- Inherits:
-
Object
- Object
- Unmagic::Icon::Configuration
- Defined in:
- lib/unmagic/icon/configuration.rb
Instance Attribute Summary collapse
-
#download_path ⇒ Object
Where ‘Unmagic::Icon::Library::Source` writes libraries by default.
-
#libraries ⇒ Object
Returns the value of attribute libraries.
-
#paths ⇒ Object
Returns the value of attribute paths.
Instance Method Summary collapse
-
#initialize ⇒ Configuration
constructor
A new instance of Configuration.
Constructor Details
#initialize ⇒ Configuration
Returns a new instance of Configuration.
11 12 13 14 |
# File 'lib/unmagic/icon/configuration.rb', line 11 def initialize @paths = [] @libraries = [] end |
Instance Attribute Details
#download_path ⇒ Object
Where ‘Unmagic::Icon::Library::Source` writes libraries by default. vendor/icons keeps downloaded sets out of the asset pipeline (Propshaft fingerprints app/assets/*, but the icons are inlined via File.read, never served), and reads as vendored third-party. Must be set explicitly when not running under Rails.
21 22 23 |
# File 'lib/unmagic/icon/configuration.rb', line 21 def download_path @download_path ||= default_download_path end |
#libraries ⇒ Object
Returns the value of attribute libraries.
8 9 10 |
# File 'lib/unmagic/icon/configuration.rb', line 8 def libraries @libraries end |
#paths ⇒ Object
Returns the value of attribute paths.
8 9 10 |
# File 'lib/unmagic/icon/configuration.rb', line 8 def paths @paths end |